@@ -195,7 +195,7 @@ class UsersAndGroup(object):
             if 'groups' in userData:
                 pGroup = self.getGroupById(userData['primaryGroupID'])
                 if pGroup not in userData['groups']:
-                    userData['groups'].appand(pGroup)
+                    userData['groups'].append(pGroup)
         if "unix_user" in userData:
             unix = userData["unix_user"]
             if type(unix) == bool:
